* [Home](index.md)
{%- if cookiecutter.type == "api" %}
* [Protobuf API Reference](protobuf-reference/)
* [Python API Reference](python-reference/)
{%- else %}
* [API Reference](reference/)
{%- endif %}
* [Contributing](CONTRIBUTING.md)
